#site_settings.py
#do not edit this file as it may be over-written
#put local customizations in local_settings.
SITE_ID = 116
SITE_DB = 'None'
DEBUG=True
TEMPLATE_DEBUG=True
PRETTYNAME='Jan Walker, Author'



#!/usr/bin/python
"""This is the overall settings module for a single Backstage Venue instance
 It will import settings from the Backstage package, and may over-ride them.
 In turn, each Backstage Site instance will import these settings, and may over-ride them."""
#
#
#### DO NOT EDIT THIS FILE ####
#
#
import os
import sys

#Assume that 'manage.py' and 'settings.py' are siblings at the root of the Backstage venue instance
VENUE_ROOT = os.path.dirname(os.path.abspath(__file__))
VENUE_PATH, VENUE_DIRNAME = os.path.split(VENUE_ROOT)
VENUE_NAME = VENUE_DIRNAME
ROOT_URLCONF = "%s.venue.urls" % VENUE_NAME

VENUE_NAME in sys.path or sys.path.append(VENUE_NAME)
VENUE_PATH in sys.path or sys.path.append(VENUE_PATH)

"""
Here, we import all the Backstage default settings,
which in turn imports all of Django's default settings, etc...
"""
from backstage.settings.backstage_settings import *

###Here, we extend and over-ride them....

#Extend INSTALLED_APPS
INSTALLED_APPS = list(INSTALLED_APPS) #cast as alist to avoid tuple issues.
VENUE_NAME in INSTALLED_APPS or INSTALLED_APPS.insert(0, VENUE_NAME)
venue_app = '%s.venue' % VENUE_NAME
venue_app in INSTALLED_APPS or INSTALLED_APPS.insert(1, venue_app)
#local_app = '%s.local' % venue_app
#local_app in INSTALLED_APPS or INSTALLED_APPS.insert(2, local_app)

#Import everything from local.settings
exec('from %s.local.settings import *' % VENUE_NAME)



import os
import backstage
from backstage.venue import use_venue
from backstage.venue import Venue

class Act():
    def __init__(self, venue, actname):
        self.venue = venue
        self.actname = actname
        self.acthome = os.path.join(self.venue.VENUE_ROOT, 'acts', actname)
        self.uwsgifile = os.path.join(self.acthome, 'uwsgi.ini')
        if not os.path.exists(self.acthome):
            print 'Act %s does not exist in venue %s' % (self.venue.VENUE_NAME, self.actname)
            raise


def new_act(venue, actname):
    """create a new Act within a backstage Venue"""
    if isinstance(venue, str):
        try:
            venue = use_venue(venue)
        except:
            venue = None
    if not isinstance(venue, Venue):
        print '%s is not a valid backstage venue' % (venue)
        return None
    actsdir = os.path.join(venue.VENUE_ROOT, 'acts')
    acthome = os.path.join(actsdir, actname)
    if os.path.exists(acthome):
        print 'A folder named %s already exists under %s' % (actname, actsdir)
        return None
    os.mkdir(acthome)
    act = Act(venue, actname)
    create_act_uwsgi_file(act)
    if act:
        s = 'created Backstage Act %s at %s' % (actname, acthome)
        print s
        s = 'using Act %s' % (act)
        print s
    return act

def create_act_uwsgi_file(act):
    """create the uwsgi ini file for a (usually) new Act. This reads in backstage/conf/uwsgi.ini.src
    and substitutes values appropriately."""
    srcfile = os.path.join(os.path.dirname(backstage.__file__),'conf/uwsgi.ini.src')
    with open(srcfile,'r') as f:
        srcdata = f.read()
    outfile = os.path.join(act.acthome,'uwsgi.ini')
    o = open(outfile,'w')
    o.write(srcdata.format(VENUE_ROOT=act.venue.VENUE_ROOT, VENUE_NAME=act.venue.VENUE_NAME, ACT_NAME=act.actname))
    o.close()
    return

def copy_act_skel(act):
    """copy the skeleton files into the Act instance folder"""



import os
import sys
f = __file__
p = os.path.abspath(f)
d = os.path.dirname(p)
base, module = os.path.split(d)
sys.path.insert(0, base)
os.environ.setdefault("DJANGO_SETTINGS_MODULE", "%s.settings" % module)
from django.core.wsgi import get_wsgi_application
application=get_wsgi_application()
